Struct orml_tokens::BalanceLock [−][src]
pub struct BalanceLock<Balance> {
pub id: LockIdentifier,
pub amount: Balance,
}Expand description
A single lock on a balance. There can be many of these on an account and they “overlap”, so the same balance is frozen by multiple locks.
Fields
id: LockIdentifierAn identifier for this lock. Only one lock may be in existence for each identifier.
amount: BalanceThe amount which the free balance may not drop below when this lock is in effect.