Struct orml_tokens::Mapper [−][src]
pub struct Mapper<AccountId, T, C, B, GetCurrencyId>(_);Trait Implementations
impl<AccountId, T, C, B, GetCurrencyId> Inspect<AccountId> for Mapper<AccountId, T, C, B, GetCurrencyId> where
T: Inspect<AccountId>,
C: ConvertBalance<<T as Inspect<AccountId>>::Balance, B, AssetId = <T as Inspect<AccountId>>::AssetId>,
B: BalanceT,
GetCurrencyId: Get<<T as Inspect<AccountId>>::AssetId>,
impl<AccountId, T, C, B, GetCurrencyId> Inspect<AccountId> for Mapper<AccountId, T, C, B, GetCurrencyId> where
T: Inspect<AccountId>,
C: ConvertBalance<<T as Inspect<AccountId>>::Balance, B, AssetId = <T as Inspect<AccountId>>::AssetId>,
B: BalanceT,
GetCurrencyId: Get<<T as Inspect<AccountId>>::AssetId>,
type Balance = B
type Balance = B
Scalar type for representing balance of an account.
The total amount of issuance in the system.
The minimum balance any single account may have.
Get the maximum amount that who can withdraw/transfer successfully.
Returns true if the balance of who may be increased by amount.
Returns Failed if the balance of who may not be decreased by amount, otherwise
the consequence. Read more
impl<AccountId, T, C, B, GetCurrencyId> Mutate<AccountId> for Mapper<AccountId, T, C, B, GetCurrencyId> where
T: Mutate<AccountId, Balance = B>,
C: ConvertBalance<<T as Inspect<AccountId>>::Balance, B, AssetId = <T as Inspect<AccountId>>::AssetId>,
B: BalanceT,
GetCurrencyId: Get<<T as Inspect<AccountId>>::AssetId>,
impl<AccountId, T, C, B, GetCurrencyId> Mutate<AccountId> for Mapper<AccountId, T, C, B, GetCurrencyId> where
T: Mutate<AccountId, Balance = B>,
C: ConvertBalance<<T as Inspect<AccountId>>::Balance, B, AssetId = <T as Inspect<AccountId>>::AssetId>,
B: BalanceT,
GetCurrencyId: Get<<T as Inspect<AccountId>>::AssetId>,
Increase the balance of who by exactly amount, minting new tokens. If that isn’t
possible then an Err is returned and nothing is changed. Read more
Decrease the balance of who by at least amount, possibly slightly more in the case of
minimum_balance requirements, burning the tokens. If that isn’t possible then an Err is
returned and nothing is changed. If successful, the amount of tokens reduced is returned. Read more
Attempt to reduce the balance of who by as much as possible up to amount, and possibly
slightly more due to minimum_balance requirements. If no decrease is possible then an Err
is returned and nothing is changed. If successful, the amount of tokens reduced is returned. Read more
impl<AccountId, T, C, B, GetCurrencyId> Transfer<AccountId> for Mapper<AccountId, T, C, B, GetCurrencyId> where
T: Transfer<AccountId, Balance = B>,
C: ConvertBalance<<T as Inspect<AccountId>>::Balance, B, AssetId = <T as Inspect<AccountId>>::AssetId>,
B: BalanceT,
GetCurrencyId: Get<<T as Inspect<AccountId>>::AssetId>,
impl<AccountId, T, C, B, GetCurrencyId> Transfer<AccountId> for Mapper<AccountId, T, C, B, GetCurrencyId> where
T: Transfer<AccountId, Balance = B>,
C: ConvertBalance<<T as Inspect<AccountId>>::Balance, B, AssetId = <T as Inspect<AccountId>>::AssetId>,
B: BalanceT,
GetCurrencyId: Get<<T as Inspect<AccountId>>::AssetId>,